#
# spec file for package dialog
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define src_date 20171209
%define somajor 14
Name:           dialog
Version:        1.3
Release:        lp152.4.6
Summary:        Menus and Input Boxes for Shell Scripts
License:        LGPL-2.1-only
Group:          Development/Tools/Other
Url:            http://invisible-island.net/dialog/
Source0:        ftp://ftp.invisible-island.net/dialog/%{name}-%{version}-%{src_date}.tgz
Source1:        ftp://ftp.invisible-island.net/dialog/%{name}-%{version}-%{src_date}.tgz.asc
Source2:        %{name}.keyring
Source3:        dialog.rc
Source4:        dialog.ko.po.bz2
# PATCH-FIX-OPENSUSE : fix shadow during resizing terminal
Patch0:         dialog-1.2-20121230.dif
Patch1:         textbox-file_size.patch
Patch2:         dialog-gcc-warnings.patch
BuildRequires:  libtool
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
Requires:       terminfo-base
Recommends:     %{name}-lang
Suggests:       terminfo

%description
This program lets you use menus and dialog boxes in shell scripts.

%package     -n libdialog%{somajor}
Summary:        Menus and Input Boxes for Shell Scripts
Group:          System/Libraries

%description -n libdialog%{somajor}
This program lets you use menus and dialog boxes in shell scripts.

%package        devel
Summary:        Menus and Input Boxes for Shell Scripts
Group:          Development/Libraries/Other
Requires:       libdialog%{somajor} = %{version}

%description    devel
This program lets you use menus and dialog boxes in shell scripts.

%package        examples
Summary:        Examples of using dialog tool
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}
BuildArch:      noarch

%description    examples
Examples of using menus and dialog boxes in shell scripts.

%lang_package

%prep
%setup -q -n %{name}-%{version}-%{src_date}
bzcat %{SOURCE4} > po/ko.po
%patch0
%patch1
%patch2 -p1

%build
    CC=gcc
    LIBS=""
    CFLAGS="%{optflags} -pipe -Wall"
    for ncurses_conf in ncursesw6-config ncurstesw5-config ; do
	ncurses_conf=$(type -p $ncurses_conf 2> /dev/null) || continue
	LIBS="${LIBS:+$LIBS }$($ncurses_conf --libs)"
	CFLAGS="${CFLAGS:+$CFLAGS }$($ncurses_conf --cflags)"
	NCURSES_CONFIG=$ncurses_conf
	export NCURSES_CONFIG
	break
    done
    export CC LIBS CFLAGS

%configure \
    --enable-nls \
    --enable-included-msgs \
    --enable-widec \
    --with-ncursesw \
    --with-libtool \
    --disable-rpath-hack \
    --includedir=%{_includedir}/dialog

# libtool seems to be broken in shell function func_lalib_unsafe_p()
exec 0</dev/null
make %{?_smp_mflags}

%install
# libtool seems to be broken in shell function func_lalib_unsafe_p()
exec 0</dev/null
%make_install

rm -rf %{buildroot}%{_libdir}/.libs
find %{buildroot} -type f -name "*.la" -delete -print
find %{buildroot}%{_libdir} -name '*.a' -type f -delete -print

rm -rf %{buildroot}%{_datadir}/locale/mg/ # Malagasy (Malayalam??)
rm -rf %{buildroot}%{_datadir}/locale/rm/ # Rhaeto-Romance

mkdir %{buildroot}/etc
install -m 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/dialogrc
%find_lang %{name}

%post -n libdialog%{somajor} -p /sbin/ldconfig
%postun -n libdialog%{somajor} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc CHANGES README VERSION COPYING
%config(noreplace) %{_sysconfdir}/dialogrc
%{_bindir}/dialog
%{_mandir}/man1/dialog.1%{ext_man}

%files -n libdialog%{somajor}
%defattr(-,root,root)
%{_libdir}/libdialog.so.%{somajor}*

%files devel
%defattr(-,root,root)
%{_bindir}/dialog-config
%{_libdir}/libdialog.so
%{_includedir}/dialog/
%{_mandir}/man3/dialog.3%{ext_man}

%files examples
%defattr(-,root,root)
%doc samples/*

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Tue May 29 2018 werner@suse.de
- Update to version 1.3-20171209
  + update ftp url in test-packages.
  + modify test-packages to use recommended compiler/linker flags.
  + improved configure macros AM_WITH_NLS, CF_CC_ENV_FLAGS,
    CF_CURSES_LIBS, CF_NCURSES_CONFIG, CF_SHARED_OPTS, CF_WITH_LIBTOOL,
    CF__INTL_BODY.
  + update config.guess, config.sub
- Add patch textbox-file_size.patch to fix bug bsc#1094836
* Tue Jun  6 2017 mpluskal@suse.com
- Update to version 1.3-20170509:
  * improved configure macros CF_ADD_CFLAGS, CF_CC_ENV_FLAGS, and
  CF_SHARED_OPTS.
  * updated hu.po and tr.po from
  http://translationproject.org/latest/dialog/
  * update config.guess, config.sub
* Tue Mar  7 2017 p.drouand@gmail.com
- Update to version 1.3-20170131
  * use DLG_TRACE macro consistently to make "--disable-trace" configure
  option work.
  * modify buildlist widget to support option "--reorder" for to allow
    user to reorder the data based on the sequence of selections
    (discussion with Paraic O'Ceallaigh).
  * fill background color on unused parts of buildlist.
  * fix a minor error in buildlist which let pageup switch columns.
  * change several calls to dlg_trace_msg to prefix with "#" to make
    the trace logs more consistent for parsing.
  * add samples/run_test.sh
  * further improve performance with very long command-lines by changes
    to howmany_tags().
  * modify dlg_string_to_argv() to convert escaped double-quotes to
    plain double-quotes when within a double-quoted string.
  * modify makefile to apply CFLAGS to linking
  * modify dlg_string_to_argv() to ignore escaped newlines except when
    quoted, fixing a problem with samples/checklist9.
  * interpret $DIALOGOPTS before expanding "--file", etc., to allow
    the environment variable to turn on tracing in that process.
  * improve performance when processing very long command lines, e.g.,
    using "--file" by changing dialog_opts[] to an array of pointers to
    the expanded argv[] (discussion with Lars Tauber).
  * modified autoconf macros
    + CF_CC_ENV_FLAGS amend the last change to move only the
    preprocessor, optimization and warning flags to CPPFLAGS and
    CFLAGS, leaving the residue in CC.  That happens to work for gcc's
    various "model" options, but may require tuning for other compilers
    + CF_LARGEFILE workaround for clang exit-code vs warnings
    + CF_MATH_LIB quiet strict gcc warning
    + CF_WITH_LIBTOOL fix a few places in configure/build scripts where
    DESTDIR and rpath were combined
    + CF_XOPEN_SOURCE add "uclinux" to list of Linux's
  * update config.guess, config.sub
* Fri Mar 11 2016 mpluskal@suse.com
- Update to 1.3-20160209
  * modify editbox widget to add a trailing newline if the text
    has none to ensure the last line is not ignored (report by
    Florent Rougon).
  * change mouse initialization to look for button-presses rather
    than button-clicks, for better response.
  * modify dump_curses_key() to show mouse-coding in readable form.
  * correct mapping of mouse-clicks on the day-grid in calendar
    widget when "--week-start" is used to set the start of the week
    (report by Stefan Vogtner).
  * integrated changes from Stefan Vogtner:
  * use Gregorian algorithm for leap year
  * use mktime if available; calendar was written just as it became
    standard.
- Changes for version 1.3
  * correct --infobox documentation, which said it shows an OK
    button.
  * fix a couple of place in test-scripts which referred to
    $SIG_TRAP rather than $SIG_QUIT
  * reorganize dialog.3, to use subsections for generating navigation
    pane, using man2html
  * add "--week-start" option for calendar widget (prompted by
    discussion with Stefan Vogtner).
  * add a limit-check in editbox.c to ensure that mouse-clicks
    outside the filled-in text area do not access past the end of
    the array (report by Stefan Vogtner).
  * update configure macros from ncurses changes.
  * update config.guess, config.sub
* Mon Sep 28 2015 mpluskal@suse.com
- Update to 1.2-20150920
  * decrease table value for minimum number of arguments for the
    widgets which use --no-items option
  * update configure macros:
    + use $SHELL consistently, deprecate non-POSIX shell
    + PKG_CONFIG may simply be unset - fix
    + add option to allow changing ABI version, from ncurses6.
  * fixes for two autoconf macros, CF_ADD_INCDIR and
    CF_NCURSES_CONFIG from work on ncurses.
  * build-fix for NetBSD curses
- Fix typo in previous changelog entry
* Fri May 22 2015 mpluskal@suse.com
- Add gpg signature
- Update to 1.2-20150513
  + add configure option --with-install-prefix, like ncurses.
  + add --with-screen and related configure options from ncurses-examples
    to allow building with ncurses6 test-packages.
  + update configure macros for improved coding style from lynx changes.
  + updated ro.po from
    http://translationproject.org/latest/dialog/
  + update config.guess, config.sub
  > patches by Florent Rougon:
  + fix two bugs in the "--file" option.
    + When the number of arguments read from the included file is 0, the
    code used to just skip over '--file' and its argument instead of
    removing them from the argument list, causing "Error:  Unknown
    option --file" later on.
    + In the alternative case (at least one argument read from the file),
    the previous code used to do '--j;' in order to "force rescan" of
    the inserted arguments.  However, control then flowed to outer
    blocks where a '++j;' counteracted this measure, causing "Error:
    Unknown option --msgbox" (for instance) later on.
  + modify escaping in argv.c to be more uniform, whether or not the
    backslash is found within a parameter.
* Thu Mar  5 2015 werner@suse.de
- Hack around bug in libtool as it seems to be broken in shell
  function func_lalib_unsafe_p() as this does only work if a
  file descriptor 0 exists.
* Wed Mar  4 2015 werner@suse.de
- Update to version 1.2-20150225
  + modify gauge widget to keep from erasing a second gauge widget, e.g.,
    via the "--and-widget" option.  This is a cosmetic change to match
    behavior of dialog 1.0 (report by Jason Orendorf).
  + add configure option "--with-man2html"
  + add configure options for versioned symbols, from ongoing work on
    ncurses.
  + update configure macros, e.g., for shared libraries
- Changes from 1.2- 20150125
  + suppress highlighting of character which denotes an abbreviation or
    shortcut for the OK/Cancel and other buttons for these widgets, which
    use abbreviations for the list shown on the screen:  buildlist,
    checklist/radiobox, menubox, treeview (Debian #775295).
  + add grid up/left and down/right bindings in editbox.c as synonyms for
    field prev and next, respectively when handling the OK/Cancel buttons
    (Debian #775294).
* Sun Jan  4 2015 p.drouand@gmail.com
- Update to version 1.2-20140911
  + correct malloc-size for change to prgbox.
* Thu Dec 12 2013 p.drouand@gmail.com
- Update to version 1.2-20130928
  + fix a regression in gauge widget from 1.2-20130928 changes;
    dlg_reallocate_gauge() failed when no --title option was given
- Changes from 1.2-20130923
  + fix samples/inputbox6-utf8, which had depended unnecessarily on bash.
  + improve memory caching for wide-character manipulation in gauge
    widget
  + add dlg_reallocate_gauge
  + updated configure macros to use msys changes from ncurses.
  + update config.guess, config.sub
- Changes from 1.2-20130902
  + modify makefile rule to make the ".png" filenames created by groff
    predictable.
  + add option --help-tags to allow scripts to get the item's tag field
    consistently from help- and help-item button results rather than
    getting the item's text for the latter
  + correct manpage discussion of DIALOG_ITEM_HELP versus --item-help,
    as well as --help-button return status
  + correct limit used for --hline option
  + do not print empty "[]" if a --hline option was given with an empty
    value
  + miscellaneous configure script fixes/updates.  In particular, add
    option --with-shared which builds shared libraries without a libtool
    dependency.
  + add FreeBSD port-files for test-builds.
  + update lt.po, add fa.po from
    http://translationproject.org/latest/dialog/
  + update config.guess, config.sub
- Changes from 1.2-20130523
  + modify ifdef in arrows.c to work around packages which use the
    wide-character ncursesw headers with the ncurses library
  + correct workaround for xterm alternate-screen to work with/without
    the fix made in ncurses that makes putp() always write to the
    standard output (Debian #708829).
  + improve limit-checks for checklist, in case the dialog is resized
  + add --last-key option ( Debian #697607).
- Changes from 2013/03/15
  + update zh_TW.po, add an.po from
    http://translationproject.org/latest/dialog/
- Remove dialog-libs.patch; fixed on upstream release
* Fri Jun 21 2013 werner@suse.de
- Require terminfo-base and suggest terminfo to have on many or on
  mostly all terminals valid line graphics (bnc#826171)
* Thu Feb 28 2013 werner@suse.de
- Re-add patch dialog-1.2-20121230.dif: Fix problem with moving
  shadows during terminal resize
- Use a /etc/dialogrc for openSUSE default coloring/shadow defaults
- Re-add Korean language message file
* Fri Feb 22 2013 dmitry_r@opensuse.org
- Update to version 1.2-20121230
  * See included CHANGES file for detailes
* Fri Feb 22 2013 dmitry_r@opensuse.org
- Fix libraries
  * dialog-libs.patch
* Thu Jan 31 2013 cfarrell@suse.com
- license update: LGPL-2.1
  See e.g. editbox.c
* Sun Jan 27 2013 dmitry_r@opensuse.org
- Build with libtool using
- Add devel package
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
* Sun Oct 31 2010 jengelh@medozas.de
- Use %%_smp_mflags
* Wed Sep  8 2010 werner@suse.de
- Disable gpm as it is not used for long time
* Thu Jul  1 2010 werner@suse.de
- Added korean po translation file (bnc#614248)
* Fri Dec 18 2009 jengelh@medozas.de
- Enable parallel build
* Mon Aug 18 2008 werner@suse.de
- Reflect last changes in ncurses
* Thu Aug 14 2008 werner@suse.de
- Update to version 1.1 patchlevel 20080727
- Use new ncurses ABI 6 which has extend mouse and color support
* Thu Apr 10 2008 werner@suse.de
- Update to version 1.1 patchlevel 20080316 which includes our
  shadow patch and is fully compatible with newer ncurses.
* Sat Mar 31 2007 rguenther@suse.de
- Add gpm BuildRequires
* Mon Jul 10 2006 werner@suse.de
- Update to new version 1.0 (20060221 TD)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Apr  6 2004 werner@suse.de
- More about shadows: Make them resizable.
* Thu Apr  1 2004 werner@suse.de
- Update to UTF-8 workable version, use wide char version (#37850)
* Sun Jan 11 2004 adrian@suse.de
- add %%defattr
* Thu Jun 12 2003 coolo@suse.de
- use BuildRoot
- package translations too
* Wed Jan  8 2003 werner@suse.de
- Fix bug#22787: Update to new version 0.92b (20020814 TD)
- Correct shadow support
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Fri Feb 25 2000 werner@suse.de
- Do not highlight shadows
* Fri Feb 25 2000 werner@suse.de
- ioctl: if stdout is not a tty try stdin
- Make PageUp and PageDown work as Up and Down in menubox,
  checkbox, and radiobox.
* Thu Feb 24 2000 werner@suse.de
- Security fix in gauge menu
- /usr/man -> /usr/share/man
- Small optimations for several ncurses versions
- Use RPM_OPT_FLAGS
- Make DEL/BS work on any terminal even if terminfo is broken
- Make dialogrc dump work again
- Make shadow work and enable shadow support
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu Jan  2 1997 florian@suse.de
  just recompiled for newer ncurses
